@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
   Copyright (c) 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   This program is free software; you can redistribute it and/or modify it
@@ -96,7 +96,7 @@ void CollectionExpiryPage::init()
     actionsGroup->setFlat(true); // for mutual exclusion of the radio buttons
 
     QHBoxLayout *moveToHBox = new QHBoxLayout();
-    moveToHBox->setMargin(0);
+    moveToHBox->setContentsMargins(0, 0, 0, 0);
     moveToHBox->setSpacing(6);
 
     moveToRB = new QRadioButton(actionsGroup);
@@ -131,43 +131,40 @@ void CollectionExpiryPage::load(const Akonadi::Collection &collection)
     mCollection = collection;
     init();
 
-    bool mustDeleteExpirationAttribute = false;
-    MailCommon::ExpireCollectionAttribute *attr = MailCommon::Util::expirationCollectionAttribute(mCollection, mustDeleteExpirationAttribute);
-
-    // Load the values from the folder
-    bool expiryGloballyOn = attr->isAutoExpire();
-    int daysToExpireRead, daysToExpireUnread;
-    attr->daysToExpire(daysToExpireUnread, daysToExpireRead);
-
-    if (expiryGloballyOn
-        && attr->readExpireUnits() != ExpireCollectionAttribute::ExpireNever
-        && daysToExpireRead >= 0) {
-        expireReadMailCB->setChecked(true);
-        expireReadMailSB->setValue(daysToExpireRead);
-    }
-    if (expiryGloballyOn
-        && attr->unreadExpireUnits() != ExpireCollectionAttribute::ExpireNever
-        && daysToExpireUnread >= 0) {
-        expireUnreadMailCB->setChecked(true);
-        expireUnreadMailSB->setValue(daysToExpireUnread);
-    }
-
-    if (attr->expireAction() == ExpireCollectionAttribute::ExpireDelete) {
-        deletePermanentlyRB->setChecked(true);
-    } else {
-        moveToRB->setChecked(true);
-    }
-
-    Akonadi::Collection::Id destFolderID = attr->expireToFolderId();
-    if (destFolderID > 0) {
-        Akonadi::Collection destFolder = Kernel::self()->collectionFromId(destFolderID);
-        if (destFolder.isValid()) {
-            folderSelector->setCollection(destFolder);
+    const MailCommon::ExpireCollectionAttribute *attr = collection.attribute<MailCommon::ExpireCollectionAttribute>();
+    if (attr) {
+        // Load the values from the folder
+        bool expiryGloballyOn = attr->isAutoExpire();
+        int daysToExpireRead, daysToExpireUnread;
+        attr->daysToExpire(daysToExpireUnread, daysToExpireRead);
+        if (expiryGloballyOn
+                && attr->readExpireUnits() != ExpireCollectionAttribute::ExpireNever
+                && daysToExpireRead >= 0) {
+            expireReadMailCB->setChecked(true);
+            expireReadMailSB->setValue(daysToExpireRead);
+        }
+        if (expiryGloballyOn
+                && attr->unreadExpireUnits() != ExpireCollectionAttribute::ExpireNever
+                && daysToExpireUnread >= 0) {
+            expireUnreadMailCB->setChecked(true);
+            expireUnreadMailSB->setValue(daysToExpireUnread);
         }
-    }
 
-    if (mustDeleteExpirationAttribute) {
-        delete attr;
+        if (attr->expireAction() == ExpireCollectionAttribute::ExpireDelete) {
+            deletePermanentlyRB->setChecked(true);
+        } else {
+            moveToRB->setChecked(true);
+        }
+
+        Akonadi::Collection::Id destFolderID = attr->expireToFolderId();
+        if (destFolderID > 0) {
+            Akonadi::Collection destFolder = Kernel::self()->collectionFromId(destFolderID);
+            if (destFolder.isValid()) {
+                folderSelector->setCollection(destFolder);
+            }
+        }
+    } else {
+        deletePermanentlyRB->setChecked(true);
     }
     slotUpdateControls();
     mChanged = false;
@@ -180,9 +177,8 @@ void CollectionExpiryPage::save(Akonadi::Collection &collection)
     }
 }
 
-void CollectionExpiryPage::saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool _expireNow)
+void CollectionExpiryPage::saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool expireNow)
 {
-    bool expireNow = _expireNow;
     bool enableGlobally = expireReadMailCB->isChecked() || expireUnreadMailCB->isChecked();
     const Akonadi::Collection expireToFolder = folderSelector->collection();
     if (enableGlobally && moveToRB->isChecked() && !expireToFolder.isValid()) {
