@@ -21,12 +21,10 @@
 #define MAILCOMMON_FILTERACTIONWITHCOMMAND_H
 
 #include "filteractionwithurl.h"
-
+#include <QVector>
 class QTemporaryFile;
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 class FilterActionWithCommand : public FilterActionWithUrl
 {
     Q_OBJECT
@@ -40,22 +38,22 @@ public:
     /**
      * @copydoc FilterAction::createParamWidget
      */
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const override;
 
     /**
      * @copydoc FilterAction::applyParamWidgetValue
      */
-    void applyParamWidgetValue(QWidget *paramWidget) Q_DECL_OVERRIDE;
+    void applyParamWidgetValue(QWidget *paramWidget) override;
 
     /**
      * @copydoc FilterAction::setParamWidgetValue
      */
-    void setParamWidgetValue(QWidget *paramWidget) const Q_DECL_OVERRIDE;
+    void setParamWidgetValue(QWidget *paramWidget) const override;
 
     /**
      * @copydoc FilterAction::clearParamWidget
      */
-    void clearParamWidget(QWidget *paramWidget) const Q_DECL_OVERRIDE;
+    void clearParamWidget(QWidget *paramWidget) const override;
 
     /**
      * Substitutes various placeholders for data from the message
@@ -64,12 +62,10 @@ public:
      * the name of a tempfile holding the n'th message part, with n=0
      * meaning the body of the message.
      */
-    virtual QString substituteCommandLineArgsFor(const KMime::Message::Ptr &aMsg,
-            QList<QTemporaryFile *> &aTempFileList) const;
+    Q_REQUIRED_RESULT virtual QString substituteCommandLineArgsFor(const KMime::Message::Ptr &aMsg, QVector<QTemporaryFile *> &aTempFileList) const;
 
-    virtual ReturnCode genericProcess(ItemContext &context, bool filtering) const;
+    Q_REQUIRED_RESULT virtual ReturnCode genericProcess(ItemContext &context, bool filtering) const;
 };
-
 }
 
 #endif
